==> mayan-edms-3.5.tar.gz: mayan-edms-3.5/mayan/apps/dynamic_search/api_views.py <==
from django.utils.encoding import force_text

from rest_framework.exceptions import ParseError

from mayan.apps.rest_api import generics

from .classes import SearchBackend, SearchModel
from .mixins import SearchModelAPIMixin
from .serializers import SearchModelSerializer


class APISearchView(SearchModelAPIMixin, generics.ListAPIView):
    """
    get: Perform a search operation
    """
    def get_queryset(self):
        search_model = self.get_search_model()

        # Override serializer class just before producing the queryset of
        # search results
        self.serializer_class = search_model.serializer

        if search_model.permission:
            self.mayan_object_permissions = {'GET': (search_model.permission,)}

        try:
            queryset = SearchBackend.get_instance().search(
                search_model=search_model,
                query_string=self.request.GET, user=self.request.user
            )
        except Exception as exception:
            raise ParseError(force_text(exception))

        return queryset

    def get_serializer(self, *args, **kwargs):
        if self.get_search_model_name():
            return super(APISearchView, self).get_serializer(*args, **kwargs)
        else:
            return None


class APIAdvancedSearchView(SearchModelAPIMixin, generics.ListAPIView):
    """
    get: Perform an advanced search operation
    """
    def get_queryset(self):
        self.search_model = self.get_search_model()

        # Override serializer class just before producing the queryset of
        # search results
        self.serializer_class = self.search_model.serializer

        if self.search_model.permission:
            self.mayan_object_permissions = {
                'GET': (self.search_model.permission,)
            }

        if self.request.GET.get('_match_all', 'off') == 'on':
            global_and_search = True
        else:
            global_and_search = False

        try:
            queryset = SearchBackend.get_instance().search(
                global_and_search=global_and_search,
                query_string=self.request.GET,
                search_model=self.search_model, user=self.request.user
            )
        except Exception as exception:
            raise ParseError(force_text(exception))

        return queryset

    def get_serializer(self, *args, **kwargs):
        if self.get_search_model_name():
            return super(APIAdvancedSearchView, self).get_serializer(*args, **kwargs)
        else:
            return None


class APISearchModelList(generics.ListAPIView):
    """
    get: Returns a list of all the available search models.
    """
    serializer_class = SearchModelSerializer

    def get_queryset(self):
        # This changes after the initial startup as search models are
        # automatically loaded.
        return SearchModel.all()

==> mayan-edms-4.0.7.tar.gz: mayan-edms-4.0.7/mayan/apps/dynamic_search/api_views.py <==
from django.utils.encoding import force_text

from rest_framework.exceptions import ParseError

from mayan.apps.rest_api import generics

from .api_view_mixins import SearchModelAPIViewMixin
from .classes import SearchBackend, SearchModel
from .serializers import SearchModelSerializer


class APISearchView(SearchModelAPIViewMixin, generics.ListAPIView):
    """
    get: Perform a search operation
    """
    def get_queryset(self):
        search_model = self.get_search_model()

        # Override serializer class just before producing the queryset of
        # search results
        self.serializer_class = search_model.serializer

        if search_model.permission:
            self.mayan_object_permissions = {'GET': (search_model.permission,)}

        try:
            queryset = SearchBackend.get_instance().search(
                search_model=search_model,
                query_string=self.request.GET, user=self.request.user
            )
        except Exception as exception:
            raise ParseError(force_text(s=exception))

        return queryset

    def get_serializer(self, *args, **kwargs):
        if self.get_search_model_name():
            return super().get_serializer(*args, **kwargs)
        else:
            return None


class APIAdvancedSearchView(SearchModelAPIViewMixin, generics.ListAPIView):
    """
    get: Perform an advanced search operation
    """
    def get_queryset(self):
        self.search_model = self.get_search_model()

        # Override serializer class just before producing the queryset of
        # search results
        self.serializer_class = self.search_model.serializer

        if self.search_model.permission:
            self.mayan_object_permissions = {
                'GET': (self.search_model.permission,)
            }

        if self.request.GET.get('_match_all', 'off') == 'on':
            global_and_search = True
        else:
            global_and_search = False

        try:
            queryset = SearchBackend.get_instance().search(
                global_and_search=global_and_search,
                query_string=self.request.GET,
                search_model=self.search_model, user=self.request.user
            )
        except Exception as exception:
            raise ParseError(force_text(s=exception))

        return queryset

    def get_serializer(self, *args, **kwargs):
        if self.get_search_model_name():
            return super().get_serializer(*args, **kwargs)
        else:
            return None


class APISearchModelList(generics.ListAPIView):
    """
    get: Returns a list of all the available search models.
    """
    serializer_class = SearchModelSerializer

    def get_queryset(self):
        # This changes after the initial startup as search models are
        # automatically loaded.
        return SearchModel.all()
